@@ -6,6 +6,7 @@
 #include "drkonqibackends.h"
 
 #include <cerrno>
+#include <chrono>
 #include <cstdlib>
 #include <signal.h>
 #include <sys/types.h>
@@ -25,14 +26,15 @@
 #include "debugger.h"
 #include "debuggermanager.h"
 #include "drkonqi.h"
+#include "linuxprocmapsparser.h"
 
 #ifdef Q_OS_MACOS
 #include <AvailabilityMacros.h>
 #endif
 
-AbstractDrKonqiBackend::~AbstractDrKonqiBackend()
-{
-}
+using namespace std::chrono_literals;
+
+AbstractDrKonqiBackend::~AbstractDrKonqiBackend() = default;
 
 bool AbstractDrKonqiBackend::init()
 {
@@ -41,11 +43,9 @@ bool AbstractDrKonqiBackend::init()
     return true;
 }
 
-KCrashBackend::KCrashBackend()
-    : QObject()
-    , AbstractDrKonqiBackend()
-    , m_state(ProcessRunning)
+void AbstractDrKonqiBackend::prepareForDebugger()
 {
+    Q_EMIT preparedForDebugger();
 }
 
 KCrashBackend::~KCrashBackend()
@@ -92,7 +92,7 @@ bool KCrashBackend::init()
         // to reach the alarm(0); call in kdeui/util/kcrash.cpp line 406 or else
         // if we stop it before this call, pending alarm signals will kill the
         // process when we try to continue it.
-        QTimer::singleShot(2000, this, &KCrashBackend::stopAttachedProcess);
+        QTimer::singleShot(2s, this, &KCrashBackend::stopAttachedProcess);
     }
 #endif
 
@@ -105,88 +105,66 @@ bool KCrashBackend::init()
 
 CrashedApplication *KCrashBackend::constructCrashedApplication()
 {
-    CrashedApplication *a = new CrashedApplication(this);
-    a->m_datetime = QDateTime::currentDateTime();
-    a->m_name = DrKonqi::programName();
-    a->m_version = DrKonqi::appVersion();
-    a->m_reportAddress = BugReportAddress(DrKonqi::bugAddress());
-    a->m_pid = DrKonqi::pid();
-    a->m_signalNumber = DrKonqi::signal();
-    a->m_restarted = DrKonqi::isRestarted();
-    a->m_thread = DrKonqi::thread();
+    const auto pid = DrKonqi::pid();
+    QFileInfo executable;
+    QString fakeBaseName;
+    bool hasDeletedFiles = false;
 
     // try to determine the executable that crashed
-    const QString procPath(QStringLiteral("/proc/%1").arg(a->m_pid));
+    const QString procPath(QStringLiteral("/proc/%1").arg(pid));
     const QString exeProcPath(procPath + QStringLiteral("/exe"));
     if (QFileInfo(exeProcPath).exists()) {
         // on linux, the fastest and most reliable way is to get the path from /proc
         qCDebug(DRKONQI_LOG) << "Using /proc to determine executable path";
         const QString exePath = QFile::symLinkTarget(exeProcPath);
 
-        a->m_executable.setFile(exePath);
-        if (DrKonqi::isKdeinit() || a->m_executable.fileName().startsWith(QLatin1String("python"))) {
-            a->m_fakeBaseName = DrKonqi::appName();
+        executable.setFile(exePath);
+        if (DrKonqi::isKdeinit() || executable.fileName().startsWith(QLatin1String("python"))) {
+            fakeBaseName = DrKonqi::appName();
         }
 
-        QDir mapFilesDir(procPath + QStringLiteral("/map_files"));
-        mapFilesDir.setFilter(mapFilesDir.filter() | QDir::System); // proc is system!
-
-        // "/bin/foo (deleted)" is how the kernel tells us that a file has been deleted since
-        // it was mmap'd.
-        QRegularExpression expression(QStringLiteral("(?<path>.+) \\(deleted\\)$"));
-        // For the map_files we filter only .so files to ensure that
-        // we don't trip over cache files or the like, as a result we
-        // manually need to check if the main exe was deleted and add
-        // it.
-        // NB: includes .so* and .py* since we also implicitly support snakes to
-        //   a degree
-        QRegularExpression soExpression(QStringLiteral("(?<path>.+\\.(so|py)([^/]*)) \\(deleted\\)$"));
-
-        bool hasDeletedFiles = false;
-
-        const auto exeMatch = expression.match(exePath);
-        if (exeMatch.isValid() && exeMatch.hasMatch()) {
-            hasDeletedFiles = true;
+        const QString mapsPath = procPath + QStringLiteral("/maps");
+        QFile mapsFile(mapsPath);
+        if (mapsFile.open(QFile::ReadOnly)) {
+            hasDeletedFiles = LinuxProc::hasMapsDeletedFiles(exePath, mapsFile.readAll(), LinuxProc::Check::DeletedMarker);
+        } else {
+            qCWarning(DRKONQI_LOG) << "failed to open maps file" << mapsPath;
         }
 
-        const auto list = mapFilesDir.entryInfoList();
-        for (auto it = list.constBegin(); !hasDeletedFiles && it != list.constEnd(); ++it) {
-            const auto match = soExpression.match(it->symLinkTarget());
-            if (!match.isValid() || !match.hasMatch()) {
-                continue;
-            }
-            const QString path = match.captured(QStringLiteral("path"));
-            if (path.startsWith(QStringLiteral("/memfd"))) {
-                // Qml.so's JIT shows up under memfd. This is a false positive against our regex.
-                continue;
-            }
-            hasDeletedFiles = true;
-        }
-
-        a->m_hasDeletedFiles = hasDeletedFiles;
-
         qCDebug(DRKONQI_LOG) << "exe" << exePath << "has deleted files:" << hasDeletedFiles;
     } else {
         if (DrKonqi::isKdeinit()) {
-            a->m_executable = QFileInfo(QStandardPaths::findExecutable(QStringLiteral("kdeinit5")));
-            a->m_fakeBaseName = DrKonqi::appName();
+            executable = QFileInfo(QStandardPaths::findExecutable(QStringLiteral("kdeinit5")));
+            fakeBaseName = DrKonqi::appName();
         } else {
             QFileInfo execPath(DrKonqi::appName());
             if (execPath.isAbsolute()) {
-                a->m_executable = execPath;
+                executable = execPath;
             } else if (!DrKonqi::appPath().isEmpty()) {
                 QDir execDir(DrKonqi::appPath());
-                a->m_executable = execDir.absoluteFilePath(execPath.fileName());
+                executable = execDir.absoluteFilePath(execPath.fileName());
             } else {
-                a->m_executable = QFileInfo(QStandardPaths::findExecutable(execPath.fileName()));
+                executable = QFileInfo(QStandardPaths::findExecutable(execPath.fileName()));
             }
         }
     }
 
-    qCDebug(DRKONQI_LOG) << "Executable is:" << a->m_executable.absoluteFilePath();
-    qCDebug(DRKONQI_LOG) << "Executable exists:" << a->m_executable.exists();
+    qCDebug(DRKONQI_LOG) << "Executable is:" << executable.absoluteFilePath();
+    qCDebug(DRKONQI_LOG) << "Executable exists:" << executable.exists();
 
-    return a;
+    return new CrashedApplication(pid,
+                                  DrKonqi::thread(),
+                                  DrKonqi::signal(),
+                                  executable,
+                                  DrKonqi::appVersion(),
+                                  BugReportAddress(DrKonqi::bugAddress()),
+                                  DrKonqi::programName(),
+                                  DrKonqi::productName(),
+                                  QDateTime::currentDateTime(),
+                                  DrKonqi::isRestarted(),
+                                  hasDeletedFiles,
+                                  fakeBaseName,
+                                  this);
 }
 
 DebuggerManager *KCrashBackend::constructDebuggerManager()
@@ -202,7 +180,7 @@ DebuggerManager *KCrashBackend::constructDebuggerManager()
 #endif
 
     Debugger firstKnownGoodDebugger, preferredDebugger;
-    foreach (const Debugger &debugger, internalDebuggers) {
+    for (const Debugger &debugger : std::as_const(internalDebuggers)) {
         qCDebug(DRKONQI_LOG) << "Check debugger if" << debugger.displayName() << "[" << debugger.codeName() << "]"
                              << "is installed:" << debugger.isInstalled();
         if (!firstKnownGoodDebugger.isValid() && debugger.isInstalled()) {
