@@ -25,9 +25,7 @@
 #include <QDBusReply>
 
 #include <config-drkonqi.h>
-#if HAVE_X11
-#include <QX11Info>
-#endif
+
 #ifdef Q_OS_MACOS
 #include <KWindowSystem>
 #endif
@@ -48,7 +46,7 @@ namespace
 {
 void openDrKonqiDialog()
 {
-    DrKonqiDialog *w = new DrKonqiDialog();
+    auto *w = new DrKonqiDialog();
     QObject::connect(qApp, &QCoreApplication::aboutToQuit, w, &QObject::deleteLater);
     QObject::connect(w, &DrKonqiDialog::rejected, qApp, &QApplication::quit);
     w->show();
@@ -59,7 +57,7 @@ void openDrKonqiDialog()
 
 void requestDrKonqiDialog(bool restarted, bool interactionAllowed)
 {
-    StatusNotifier *statusNotifier = new StatusNotifier();
+    auto *statusNotifier = new StatusNotifier();
     statusNotifier->setActivationAllowed(interactionAllowed);
     if (interactionAllowed) {
         statusNotifier->show();
@@ -124,6 +122,7 @@ int main(int argc, char *argv[])
     const QCommandLineOption appVersionOption(QStringLiteral("appversion"), i18nc("@info:shell", "The <version> of the program"), QStringLiteral("version"));
     const QCommandLineOption bugAddressOption(QStringLiteral("bugaddress"), i18nc("@info:shell", "The bug <address> to use"), QStringLiteral("address"));
     const QCommandLineOption programNameOption(QStringLiteral("programname"), i18nc("@info:shell", "Translated <name> of the program"), QStringLiteral("name"));
+    const QCommandLineOption productNameOption(QStringLiteral("productname"), i18nc("@info:shell", "Bugzilla product name"), QStringLiteral("name"));
     const QCommandLineOption pidOption(QStringLiteral("pid"), i18nc("@info:shell", "The <PID> of the program"), QStringLiteral("pid"));
     const QCommandLineOption startupIdOption(QStringLiteral("startupid"), i18nc("@info:shell", "Startup <ID> of the program"), QStringLiteral("id"));
     const QCommandLineOption kdeinitOption(QStringLiteral("kdeinit"), i18nc("@info:shell", "The program was started by kdeinit"));
@@ -142,6 +141,7 @@ int main(int argc, char *argv[])
                        appVersionOption,
                        bugAddressOption,
                        programNameOption,
+                       productNameOption,
                        pidOption,
                        startupIdOption,
                        kdeinitOption,
@@ -178,21 +178,16 @@ int main(int argc, char *argv[])
     DrKonqi::setAppVersion(parser.value(appVersionOption));
     DrKonqi::setBugAddress(parser.value(bugAddressOption));
     DrKonqi::setProgramName(parser.value(programNameOption));
+    DrKonqi::setProductName(parser.value(productNameOption));
     DrKonqi::setPid(parser.value(pidOption).toInt());
     DrKonqi::setKdeinit(parser.isSet(kdeinitOption));
     DrKonqi::setSafer(parser.isSet(saferOption));
     DrKonqi::setRestarted(parser.isSet(restartedOption));
     DrKonqi::setKeepRunning(parser.isSet(keepRunningOption));
     DrKonqi::setThread(parser.value(threadOption).toInt());
+    DrKonqi::setStartupId(parser.value(startupIdOption));
     auto forceDialog = parser.isSet(dialogOption);
 
-#if HAVE_X11
-    const QString startupId = parser.value(startupIdOption);
-    if (!startupId.isEmpty()) {
-        QX11Info::setNextStartupId(startupId.toUtf8());
-    }
-#endif
-
     if (!DrKonqi::init()) {
         return 1;
     }
